scxpand.lightgbm.lightgbm\_params
=================================

.. automodule:: scxpand.lightgbm.lightgbm_params

   
   .. rubric:: Classes

   .. autosummary::
   
      BoostingType
      LightGBMParams
      MetricType
      ObjectiveType
   